@@ -3,4 +3,4 @@ import asyncio
 
 
 def run(coroutine: Coroutine):
-    return asyncio.get_event_loop().run_until_complete(coroutine)
+    return asyncio.run(coroutine)
