@@ -1,4 +1,5 @@
 import canopy
+import asyncio
 import integration_tests
 
 default_car_name = 'Canopy F1 Car 2019'
@@ -7,6 +8,7 @@ default_car_name = 'Canopy F1 Car 2019'
 class TestSynchronous:
 
     def test_synchronous_call(self):
+        asyncio.set_event_loop(asyncio.new_event_loop())
         with integration_tests.Environment() as environment:
             default_car = canopy.run(canopy.load_default_config(
                 environment.session,
